Index: app/menus/menu_model.h |
diff --git a/app/menus/menu_model.h b/app/menus/menu_model.h |
index 62732cd2be5f78bc1a0fe9a6bbcd455ae35438cf..7648da4fe14be312d10d9b654d33589819a8aa79 100644 |
--- a/app/menus/menu_model.h |
+++ b/app/menus/menu_model.h |
@@ -63,10 +63,11 @@ class MenuModel { |
// Returns the label of the item at the specified index. |
virtual string16 GetLabelAt(int index) const = 0; |
- // Returns true if the label at the specified index can change over the course |
- // of the menu's lifetime. If this function returns true, the label of the |
- // menu item will be updated each time the menu is shown. |
- virtual bool IsLabelDynamicAt(int index) const = 0; |
+ // Returns true if the menu item (label/icon) at the specified index can |
+ // change over the course of the menu's lifetime. If this function returns |
+ // true, the label and icon of the menu item will be updated each time the |
+ // menu is shown. |
+ virtual bool IsItemDynamicAt(int index) const = 0; |
// Returns the font use for the label at the specified index. |
// If NULL, then use default font. |